@@ -6,7 +6,7 @@ pub(crate) fn get_contract_value(market_type: MarketType, pair: &str) -> Option<
             Some(if pair.starts_with("BTC") { 100.0 } else { 10.0 })
         }
         MarketType::LinearSwap | MarketType::LinearFuture => Some(1.0),
-        MarketType::Option => Some(1.0),
+        MarketType::EuropeanOption => Some(1.0),
         _ => None,
     }
 }
