@@ -137,7 +137,7 @@ lazy_static! {
 
         let mut result = HashMap::<MarketType, HashMap<String, f32>>::new();
         result.insert(MarketType::LinearSwap, linear_swap);
-        result.insert(MarketType::Option, linear_option);
+        result.insert(MarketType::EuropeanOption, linear_option);
         result
     };
 }
@@ -180,7 +180,7 @@ pub(crate) fn get_contract_value(market_type: MarketType, pair: &str) -> Option<
         MarketType::InverseSwap | MarketType::InverseFuture => {
             Some(if pair.starts_with("BTC") { 100.0 } else { 10.0 })
         }
-        MarketType::LinearSwap | MarketType::LinearFuture | MarketType::Option => {
+        MarketType::LinearSwap | MarketType::LinearFuture | MarketType::EuropeanOption => {
             Some(CONTRACT_VALUES[&market_type][pair])
         }
         _ => None,
